##############################################
# R script illustrating the use of strucural
# zeroes and composition change directives
# in RSiena.
# v. January 20, 2015
# written by Christian Steglich
##############################################

# load RSiena commands:
library(RSiena)
packageVersion("RSiena")

# set working directory to where the data are:
setwd("<put appropriate path here>")
list.files()

# read the data sets for the assignment:
friendship.net1 <- as.matrix(read.table("klas12p-friends-waveA.dat",na.strings="9"))
friendship.net2 <- as.matrix(read.table("klas12p-friends-waveB.dat",na.strings="9"))
friendship.net3 <- as.matrix(read.table("klas12p-friends-waveC.dat",na.strings="9"))
friendship.net4 <- as.matrix(read.table("klas12p-friends-waveD.dat",na.strings="9"))
primary.net <- as.matrix(read.table("klas12p-primary.dat",na.strings="9"))
demographics <- as.matrix(read.table("klas12p-demographics.dat",na.strings="0"))

# find out number of actors in data sets:
numberActors <- dim(demographics)[1]
numberActors

# ===============================================
# FIRST ANALYSIS USING STRUCTURAL ZERO TREATMENT:
# ===============================================

# identify dependent variable for the analysis:
friendship.SZ <- sienaDependent(array(c(friendship.net1,friendship.net2,
	friendship.net3,friendship.net4),dim=c(numberActors,numberActors,4)))

# identify covariates for the analysis:
sex.M <- coCovar(demographics[,1])
primary <- coDyadCovar(primary.net)

# combine data for the analysis:
Data.SZ <- sienaDataCreate(friendship.SZ,sex.M,primary)

# get effects table for model specification:
Model.SZ <- getEffects(Data.SZ)
effectsDocumentation(Model.SZ)

# generate initial descriptive outputfile:
print01Report(Data.SZ,Model.SZ,modelname="Composition-illustration-SZ")

# Take a look at the generated output file "Composition-illustration-SZ.out"
# to see how RSiena interpreted the data with structural zero codes.
# 
# From here on proceed "as usual".
# E.g., like this...

# Pick a model specification:
Model.SZ <- includeEffects(Model.SZ,X,interaction1='primary')
Model.SZ <- includeEffects(Model.SZ,sameX,interaction1='sex.M')
Model.SZ <- includeEffects(Model.SZ,transTrip,cycle3,inPop)
Model.SZ

# Create model object and estimate:
Options.SZ <- sienaAlgorithmCreate(projname='klas12pResults-SZ',cond=FALSE)
Results.SZ <- siena07(Options.SZ,data=Data.SZ,effects=Model.SZ)
Results.SZ
# If you like, you can here add a line saving the results as RData variables.

# ====================================================
# SECOND ANALYSIS USING COMPOSITION CHANGE DIRECTIVES:
# ====================================================

# change structural zeros to normal zeros:
friendship.net1[friendship.net1==10] <- 0
friendship.net2[friendship.net2==10] <- 0
friendship.net3[friendship.net3==10] <- 0
friendship.net4[friendship.net4==10] <- 0

# identify dependent variable for the analysis:
friendship.CC <- sienaDependent(array(c(friendship.net1,friendship.net2,
	friendship.net3,friendship.net4),dim=c(numberActors,numberActors,4)))

# read composition change directives:
composition <- sienaCompositionChangeFromFile("klas12p-composition.dat")
composition
# It is assumed that all entries and exits happen at the midpoint of the
# unobserved time period between observation moments.

# combine data for the analysis:
Data.CC <- sienaDataCreate(friendship.CC,sex.M,primary,composition)

# get effects table for model specification:
Model.CC <- getEffects(Data.CC)
effectsDocumentation(Model.CC)

# generate initial descriptive outputfile:
print01Report(Data.CC,Model.CC,modelname="Composition-illustration-CC")

# Take a look at the generated output file "Composition-illustration-CC.out"
# to see how RSiena interpreted the directives provided.
# 
# From here on proceed "as usual".

# E.g., as above this...

# Pick a model specification:
Model.CC <- includeEffects(Model.CC,X,interaction1='primary')
Model.CC <- includeEffects(Model.CC,sameX,interaction1='sex.M')
Model.CC <- includeEffects(Model.CC,transTrip,cycle3,inPop)
Model.CC

# Create model object and estimate:
Options.CC <- sienaModelCreate(projname='klas12pResults-CC',cond=FALSE)
Results.CC <- siena07(Options.CC,data=Data.CC,effects=Model.CC)
Results.CC
# Again, you might want to add a line saving the results as RData variables.
